@@ -1,17 +1,14 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import ModelView, ModelSQL, fields
-from trytond.wizard import Wizard, StateView, Button, StateTransition
-from trytond.report import Report
-from trytond.pyson import Eval, If
-from trytond.transaction import Transaction
+from trytond.model import ModelSQL, ModelView, fields
 from trytond.pool import Pool
+from trytond.pyson import Eval, If
+from trytond.report import Report
+from trytond.tools import timezone as tz
+from trytond.transaction import Transaction
+from trytond.wizard import Button, StateTransition, StateView, Wizard
 
-try:
-    import pytz
-    TIMEZONES = [(x, x) for x in pytz.common_timezones]
-except ImportError:
-    TIMEZONES = []
+TIMEZONES = [(z, z) for z in tz.available_timezones()]
 TIMEZONES += [(None, '')]
 
 Transaction.cache_keys.update({'company', 'employee'})
@@ -55,7 +52,7 @@ class Employee(ModelSQL, ModelView):
             'company': If(
                 Eval('company', -1) >= 0, Eval('company', None), None),
             },
-        depends=['company'],
+        depends={'company'},
         help="The party which represents the employee.")
     company = fields.Many2One('company.company', 'Company', required=True,
         help="The company to which the employee belongs.")
@@ -65,7 +62,6 @@ class Employee(ModelSQL, ModelView):
                 (),
                 )
             ],
-        depends=['end_date'],
         help="When the employee joins the company.")
     end_date = fields.Date('End Date',
         domain=[If((Eval('start_date')) & (Eval('end_date')),
@@ -73,21 +69,18 @@ class Employee(ModelSQL, ModelView):
                 (),
                 )
             ],
-        depends=['start_date'],
         help="When the employee leaves the company.")
     supervisor = fields.Many2One(
         'company.employee', "Supervisor",
         domain=[
             ('company', '=', Eval('company', -1)),
             ],
-        depends=['company'],
         help="The employee who oversees this employee.")
     subordinates = fields.One2Many(
         'company.employee', 'supervisor', "Subordinates",
         domain=[
             ('company', '=', Eval('company', -1)),
             ],
-        depends=['company'],
         help="The employees to be overseen by this employee.")
 
     @staticmethod
