@@ -1,12 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
-from trytond.tools.multivalue import migrate_property
+from trytond.report import Report
 from trytond.transaction import Transaction
 
-from trytond.report import Report
 from .model import CompanyMultiValueMixin, CompanyValueMixin
 
 
@@ -17,21 +15,6 @@ class Configuration(CompanyMultiValueMixin, metaclass=PoolMeta):
 class ConfigurationLang(CompanyValueMixin, metaclass=PoolMeta):
     __name__ = 'party.configuration.party_lang'
 
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-        if exist:
-            table = cls.__table_handler__(module_name)
-            exist &= table.column_exist('company')
-
-        super().__register__(module_name)
-
-        if not exist:
-            # Re-migrate with company
-            migrate_property(
-                'party.configuration', cls._configuration_value_field,
-                cls, cls._configuration_value_field, fields=['company'])
-
 
 class Party(CompanyMultiValueMixin, metaclass=PoolMeta):
     __name__ = 'party.party'
@@ -44,27 +27,7 @@ class PartyLang(CompanyValueMixin, metaclass=PoolMeta):
     def __setup__(cls):
         super().__setup__()
         cls.party.context['company'] = Eval('company', -1)
-        if 'company' not in cls.party.depends:
-            cls.party.depends.append('company')
-
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-        if exist:
-            table = cls.__table_handler__(module_name)
-            exist &= table.column_exist('company')
-
-        super(PartyLang, cls).__register__(module_name)
-
-        if not exist:
-            # Re-migrate with company
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        fields.append('company')
-        super(PartyLang, cls)._migrate_property(
-            field_names, value_names, fields)
+        cls.party.depends.add('company')
 
 
 class Replace(metaclass=PoolMeta):
@@ -123,8 +86,7 @@ class ContactMechanismLanguage(CompanyValueMixin, metaclass=PoolMeta):
     def __setup__(cls):
         super().__setup__()
         cls.contact_mechanism.context['company'] = Eval('company', -1)
-        if 'company' not in cls.contact_mechanism.depends:
-            cls.contact_mechanism.depends.append('company')
+        cls.contact_mechanism.depends.add('company')
 
 
 class LetterReport(Report):
