@@ -2,7 +2,6 @@
 # this repository contains the full copyright notices and license terms.
 from proteus import Model, Wizard
 from proteus.config import get_config
-
 from trytond.modules.currency.tests.tools import get_currency
 
 __all__ = ['create_company', 'get_company']
@@ -13,7 +12,7 @@ def create_company(party=None, currency=None, config=None):
     Party = Model.get('party.party', config=config)
     User = Model.get('res.user', config=config)
 
-    company_config = Wizard('company.company.config')
+    company_config = Wizard('company.company.config', config=config)
     company_config.execute('company')
     company = company_config.form
     if not party:
@@ -21,13 +20,13 @@ def create_company(party=None, currency=None, config=None):
         party.save()
     company.party = party
     if not currency:
-        currency = get_currency()
+        currency = get_currency(config=config)
     company.currency = currency
     company_config.execute('add')
 
     if not config:
         config = get_config()
-    config._context = User.get_preferences(True, config.context)
+    config._context = User.get_preferences(True, {})
     return company_config
 
 
